@@ -30,4 +30,6 @@ urlpatterns = [
         views.ProjectUsageView.as_view(), name='usage'),
     url(r'^(?P<project_id>[^/]+)/detail/$',
         views.DetailProjectView.as_view(), name='detail'),
+    url(r'^(?P<tenant_id>[^/]+)/update_quotas/$',
+        views.UpdateQuotasView.as_view(), name='update_quotas'),
 ]
