@@ -40,6 +40,7 @@ from horizon import workflows
 
 from openstack_dashboard import api
 from openstack_dashboard.utils import filters
+from openstack_dashboard.utils import settings as setting_utils
 
 from openstack_dashboard.dashboards.project.instances \
     import console as project_console
@@ -49,6 +50,8 @@ from openstack_dashboard.dashboards.project.instances \
     import tables as project_tables
 from openstack_dashboard.dashboards.project.instances \
     import tabs as project_tabs
+from openstack_dashboard.dashboards.project.instances \
+    import utils as instance_utils
 from openstack_dashboard.dashboards.project.instances \
     import workflows as project_workflows
 from openstack_dashboard.dashboards.project.networks.ports \
@@ -81,9 +84,22 @@ class IndexView(tables.PagedTableMixin, tables.DataTableView):
     def _get_images(self):
         # Gather our images to correlate our instances to them
         try:
+            # Community images have to be retrieved separately and merged,
+            # because their visibility has to be explicitly defined in the
+            # API call and the Glance API currently does not support filtering
+            # by multiple values in the visibility field.
             # TODO(gabriel): Handle pagination.
             images = api.glance.image_list_detailed(self.request)[0]
-            return dict((str(image.id), image) for image in images)
+            community_images = api.glance.image_list_detailed(
+                self.request, filters={'visibility': 'community'})[0]
+            image_map = {
+                image.id: image for image in images
+            }
+            # Images have to be filtered by their uuids; some users
+            # have default access to certain community images.
+            for image in community_images:
+                image_map.setdefault(image.id, image)
+            return image_map
         except Exception:
             exceptions.handle(self.request, ignore=True)
             return {}
@@ -112,8 +128,7 @@ class IndexView(tables.PagedTableMixin, tables.DataTableView):
         # nova network info cache is not synced. Precisely there is no
         # need to check IP addresses of all servers. It is sufficient to
         # fetch IP address information for servers recently updated.
-        if not getattr(settings,
-                       'OPENSTACK_INSTANCE_RETRIEVE_IP_ADDRESSES', True):
+        if not settings.OPENSTACK_INSTANCE_RETRIEVE_IP_ADDRESSES:
             return instances
         try:
             api.network.servers_update_addresses(self.request, instances)
@@ -155,39 +170,7 @@ class IndexView(tables.PagedTableMixin, tables.DataTableView):
 
         # Loop through instances to get flavor info.
         for instance in instances:
-            if hasattr(instance, 'image'):
-                # Instance from image returns dict
-                if isinstance(instance.image, dict):
-                    image_id = instance.image.get('id')
-                    if image_id in image_dict:
-                        instance.image = image_dict[image_id]
-                    # In case image not found in image_dict, set name to empty
-                    # to avoid fallback API call to Glance in api/nova.py
-                    # until the call is deprecated in api itself
-                    else:
-                        instance.image['name'] = _("-")
-                # Otherwise trying to get image from volume metadata
-                else:
-                    instance_volumes = [
-                        attachment
-                        for volume in volume_dict.values()
-                        for attachment in volume.attachments
-                        if attachment['server_id'] == instance.id
-                    ]
-                    # Sorting attached volumes by device name (eg '/dev/sda')
-                    instance_volumes.sort(key=lambda attach: attach['device'])
-                    # While instance from volume is being created,
-                    # it does not have volumes
-                    if instance_volumes:
-                        # Getting volume object, which is as attached
-                        # as the first device
-                        boot_volume = volume_dict[instance_volumes[0]['id']]
-                        if (hasattr(boot_volume, "volume_image_metadata") and
-                                boot_volume.volume_image_metadata['image_id'] in
-                                image_dict):
-                            instance.image = image_dict[
-                                boot_volume.volume_image_metadata['image_id']
-                            ]
+            self._populate_image_info(instance, image_dict, volume_dict)
 
             flavor_id = instance.flavor["id"]
             if flavor_id in flavor_dict:
@@ -200,6 +183,49 @@ class IndexView(tables.PagedTableMixin, tables.DataTableView):
 
         return instances
 
+    def _populate_image_info(self, instance, image_dict, volume_dict):
+        if not hasattr(instance, 'image'):
+            return
+        # Instance from image returns dict
+        if isinstance(instance.image, dict):
+            image_id = instance.image.get('id')
+            if image_id in image_dict:
+                instance.image = image_dict[image_id]
+            # In case image not found in image_dict, set name to empty
+            # to avoid fallback API call to Glance in api/nova.py
+            # until the call is deprecated in api itself
+            else:
+                instance.image['name'] = _("-")
+        # Otherwise trying to get image from volume metadata
+        else:
+            instance_volumes = [
+                attachment
+                for volume in volume_dict.values()
+                for attachment in volume.attachments
+                if attachment['server_id'] == instance.id
+            ]
+            # While instance from volume is being created,
+            # it does not have volumes
+            if not instance_volumes:
+                return
+            # Sorting attached volumes by device name (eg '/dev/sda')
+            instance_volumes.sort(key=lambda attach: attach['device'])
+            # Getting volume object, which is as attached
+            # as the first device
+            boot_volume = volume_dict[instance_volumes[0]['id']]
+            # There is a case where volume_image_metadata contains
+            # only fields other than 'image_id' (See bug 1834747),
+            # so we try to populate image information only when it is found.
+            volume_metadata = getattr(boot_volume, "volume_image_metadata", {})
+            image_id = volume_metadata.get('image_id')
+            if image_id:
+                try:
+                    instance.image = image_dict[image_id]
+                except KeyError:
+                    # KeyError occurs when volume was created from image and
+                    # then this image is deleted.
+                    pass
+
 
 def process_non_api_filters(search_opts, non_api_filter_info):
     """Process filters by non-API fields
@@ -243,11 +269,12 @@ class LaunchInstanceView(workflows.WorkflowView):
         initial = super(LaunchInstanceView, self).get_initial()
         initial['project_id'] = self.request.user.tenant_id
         initial['user_id'] = self.request.user.id
-        defaults = getattr(settings, 'LAUNCH_INSTANCE_DEFAULTS', {})
-        initial['config_drive'] = defaults.get('config_drive', False)
+        initial['config_drive'] = setting_utils.get_dict_config(
+            'LAUNCH_INSTANCE_DEFAULTS', 'config_drive')
         return initial
 
 
+# TODO(stephenfin): Migrate to CBV
 def console(request, instance_id):
     data = _('Unable to get log for instance "%s".') % instance_id
     tail = request.GET.get('length')
@@ -264,8 +291,9 @@ def console(request, instance_id):
     return http.HttpResponse(data.encode('utf-8'), content_type='text/plain')
 
 
+# TODO(stephenfin): Migrate to CBV
 def auto_console(request, instance_id):
-    console_type = getattr(settings, 'CONSOLE_TYPE', 'AUTO')
+    console_type = settings.CONSOLE_TYPE
     try:
         instance = api.nova.server_get(request, instance_id)
         console_url = project_console.get_console(request, console_type,
@@ -277,6 +305,7 @@ def auto_console(request, instance_id):
         exceptions.handle(request, msg, redirect=redirect)
 
 
+# TODO(stephenfin): Migrate to CBV
 def vnc(request, instance_id):
     try:
         instance = api.nova.server_get(request, instance_id)
@@ -288,6 +317,7 @@ def vnc(request, instance_id):
         exceptions.handle(request, msg, redirect=redirect)
 
 
+# TODO(stephenfin): Migrate to CBV
 def mks(request, instance_id):
     try:
         instance = api.nova.server_get(request, instance_id)
@@ -299,6 +329,7 @@ def mks(request, instance_id):
         exceptions.handle(request, msg, redirect=redirect)
 
 
+# TODO(stephenfin): Migrate to CBV
 def spice(request, instance_id):
     try:
         instance = api.nova.server_get(request, instance_id)
@@ -311,6 +342,7 @@ def spice(request, instance_id):
         exceptions.handle(request, msg, redirect=redirect)
 
 
+# TODO(stephenfin): Migrate to CBV
 def rdp(request, instance_id):
     try:
         instance = api.nova.server_get(request, instance_id)
@@ -432,7 +464,7 @@ class DisassociateView(forms.ModalFormView):
     template_name = 'project/instances/disassociate.html'
     success_url = reverse_lazy('horizon:project:instances:index')
     page_title = _("Disassociate floating IP")
-    submit_label = _("Disassocaite")
+    submit_label = _("Disassociate")
 
     def get_context_data(self, **kwargs):
         context = super(DisassociateView, self).get_context_data(**kwargs)
@@ -569,19 +601,9 @@ class ResizeView(workflows.WorkflowView):
             redirect = reverse("horizon:project:instances:index")
             msg = _('Unable to retrieve instance details.')
             exceptions.handle(self.request, msg, redirect=redirect)
-        flavor_id = instance.flavor['id']
         flavors = self.get_flavors()
-        if flavor_id in flavors:
-            instance.flavor_name = flavors[flavor_id].name
-        else:
-            try:
-                flavor = api.nova.flavor_get(self.request, flavor_id)
-                instance.flavor_name = flavor.name
-            except Exception:
-                msg = _('Unable to retrieve flavor information for instance '
-                        '"%s".') % instance_id
-                exceptions.handle(self.request, msg, ignore=True)
-                instance.flavor_name = _("Not available")
+        flavor = instance_utils.resolve_flavor(self.request, instance, flavors)
+        instance.flavor_name = flavor.name
         return instance
 
     @memoized.memoized_method
@@ -602,7 +624,6 @@ class ResizeView(workflows.WorkflowView):
             initial.update(
                 {'instance_id': self.kwargs['instance_id'],
                  'name': getattr(_object, 'name', None),
-                 'old_flavor_id': _object.flavor['id'],
                  'old_flavor_name': getattr(_object, 'flavor_name', ''),
                  'flavors': self.get_flavors()})
         return initial
