@@ -47,11 +47,12 @@ class SetFlavorChoiceAction(workflows.Action):
                               "_flavors_and_quotas.html")
 
     def populate_flavor_choices(self, request, context):
-        old_flavor_id = context.get('old_flavor_id')
+        old_flavor_name = context.get('old_flavor_name')
         flavors = context.get('flavors').values()
 
         # Remove current flavor from the list of flavor choices
-        flavors = [flavor for flavor in flavors if flavor.id != old_flavor_id]
+        flavors = [flavor for flavor in flavors
+                   if flavor.name != old_flavor_name]
 
         if flavors:
             if len(flavors) > 1:
