@@ -793,7 +793,7 @@ class ComputeApiTests(test.APIMockTestCase):
 
         self.assertIsInstance(ret, api.nova.Server)
         self.mock_get_microversion.assert_called_once_with(
-            mock.sentinel.request, ('instance_description',
+            mock.sentinel.request, ('multiattach', 'instance_description',
                                     'auto_allocated_network'))
         self.mock_novaclient.assert_called_once_with(
             mock.sentinel.request, version=mock.sentinel.microversion)
